/***************************************************************************
 *                                                                         *
 *   copyright (C) 2007 by Timo Benk                                       *
 *   email: tbenk@pwsafe.de                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License version 2        *
 *   as published by the Free Software Foundation.                         *
 *                                                                         *
 ***************************************************************************/

#ifndef PWS2_H
#define PWS2_H 1

#include <arpa/inet.h>
#include "config.h"
#include "pws2crypt.h"
#include "secmem.h"
#include "pws.h"

#ifdef __cplusplus
extern "C" {
#endif

/**
 * Decrypts the pws v2 file f. The header data and all entries are 
 * stored inside dat.
 *
 * pws2_init_data() must be called before using this function.
 *
 * @param dat - The pws_data_t object to be filled.
 * @param ctx - The pws_context_t context object.
 * @param f   - The PWSv2 FILE object.
 *
 * @returns 1 on success, otherwise 1 and error->error will be set to the corresponding error code.
 */
int pws2_decrypt (pws_data_t *dat, pws_context_t *ctx, FILE *f);

/**
 * Encrypt all data inside dat to the file f.
 *
 * @param dat - The pws_data_t object, holding all passowrds/notes/header information etc.
 * @param ctx - The pws_context_t context object.
 * @param f   - The FILE object.
 *
 * @returns 1 on success, otherwise 0 and error->error will be set to the corresponding error code.
 */
int pws2_encrypt (pws_data_t *dat, pws_context_t *ctx, FILE *f);

#ifdef __cplusplus
}
#endif

#endif

/* vim:set expandtab tabstop=4 shiftwidth=4 softtabstop=4 nowrap: */
